Zope.org

# 观光口译导游搜索系统

在日本，根据口译导游法（1949年法律第210号），仅限于经考试证明精通日本相关知识与充分的外语交流能力者，方可从事有偿的口译导游工作，因此，可以利用高质量的口译导游。
本网站面向访问日本的外国人旅行者，提供国家认定的观光口译导游搜索服务。
可以按地区、领域、语言及其他条件，在全国的观光口译导游中进行搜索，通过直接接触进行预约。

- 进入口译导游搜索

关于我们 >> 个人私隐政策 >> 国土交通省(english)

# Welcome to Zope.org

The Web Site for the Zope Community

Zope is an open source application server for building content management systems, intranets, portals, and custom applications. The Zope community consists of hundreds of companies and thousands of developers all over the world, working on building the platform and Zope applications. Zope is written in Python, a highly-productive, object-oriented scripting language. more

## Zope for...

New Users Introduction To Zope, About Python Web Masters Using Apache, Security, ZPT, DTML | Product Developers Developers Guide, Unit Testing Zope Developers Content Management Framework (CMF), Products, Using CVS/SVN, Bug Days

## What You can do on Zope.org

Membership gives you your own home folder on Zope.org where you can create and manage your own Zope objects. The objects you create and maintain will be available to all people who visit Zope.org.

Site visitors can find your content using the site search or by browsing your member folder.

Many pages on the zope.org site are generated by search queries - by providing metadata such as keywords with your content it can appear in automated site pages such as product or news listings. more

## Zope Training ...

Send your Zope training announcements to webmaster@zope.org

## Plone Training ...

Send your Plone training announcements to webmaster@zope.org
Powered by GUIDE 0.5.0 © 2006 The Guide-Interpreter Search System